summaryrefslogtreecommitdiff
path: root/iter_utils.py
diff options
context:
space:
mode:
Diffstat (limited to 'iter_utils.py')
-rw-r--r--iter_utils.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/iter_utils.py b/iter_utils.py
index 8cd204d..c6daddf 100644
--- a/iter_utils.py
+++ b/iter_utils.py
@@ -17,9 +17,9 @@ from typing import Any, List, Optional
class PeekingIterator(Iterator):
"""An iterator that lets you peek() at the next item on deck.
Returns None when there is no next item (i.e. when
- __next__() will produce a StopIteration exception).
+ :meth:`__next__` will produce a StopIteration exception).
>>> p = PeekingIterator(iter(range(3)))
>>> p.__next__()
@@ -17,9 +17,9 @@ from typing import Any, List, Optional
class PeekingIterator(Iterator):
- """An iterator that lets you peek() at the next item on deck.
+ """An iterator that lets you :meth:`peek` at the next item on deck.
Returns None when there is no next item (i.e. when